@@ -23,14 +23,14 @@
 
 #include "arch.h"
 
-int APP_CC
+int
 file_read_sections(int fd, struct list* names);
-int APP_CC
+int
 file_by_name_read_sections(const char* file_name, struct list* names);
-int APP_CC
+int
 file_read_section(int fd, const char* section,
                   struct list* names, struct list* values);
-int APP_CC
+int
 file_by_name_read_section(const char* file_name, const char* section,
                           struct list* names, struct list* values);
 
