@@ -41,6 +41,9 @@
 #include <netinet/in.h>
 #include <netinet/tcp.h>
 #include <sys/socket.h>
+#if defined(XRDP_ENABLE_VSOCK)
+#include <linux/vm_sockets.h>
+#endif
 #include <sys/un.h>
 #include <sys/time.h>
 #include <sys/times.h>
@@ -576,12 +579,23 @@ int
 g_sck_local_socket(void)
 {
 #if defined(_WIN32)
-    return 0;
+    return -1;
 #else
     return socket(PF_LOCAL, SOCK_STREAM, 0);
 #endif
 }
 
+/*****************************************************************************/
+int
+g_sck_vsock_socket(void)
+{
+#if defined(XRDP_ENABLE_VSOCK)
+    return socket(PF_VSOCK, SOCK_STREAM, 0);
+#else
+    return -1;
+#endif
+}
+
 /*****************************************************************************/
 /* returns error */
 int
@@ -655,6 +669,9 @@ g_sck_close(int sck)
         struct sockaddr_in sock_addr_in;
 #if defined(XRDP_ENABLE_IPV6)
         struct sockaddr_in6 sock_addr_in6;
+#endif
+#if defined(XRDP_ENABLE_VSOCK)
+        struct sockaddr_vm sock_addr_vm;
 #endif
     } sock_info;
     socklen_t sock_len = sizeof(sock_info);
@@ -695,6 +712,22 @@ g_sck_close(int sck)
                 g_snprintf(sockname, sizeof(sockname), "AF_UNIX");
                 break;
 
+#if defined(XRDP_ENABLE_VSOCK)
+
+            case AF_VSOCK:
+            {
+                struct sockaddr_vm *sock_addr_vm = &sock_info.sock_addr_vm;
+
+                g_snprintf(sockname,
+                           sizeof(sockname),
+                           "AF_VSOCK cid %d port %d",
+                           sock_addr_vm->svm_cid,
+                           sock_addr_vm->svm_port);
+                break;
+            }
+
+#endif
+
             default:
                 g_snprintf(sockname, sizeof(sockname), "unknown family %d",
                            sock_info.sock_addr.sa_family);
@@ -990,6 +1023,43 @@ g_sck_local_bind(int sck, const char *port)
 #endif
 }
 
+/*****************************************************************************/
+int
+g_sck_vsock_bind(int sck, const char *port)
+{
+#if defined(XRDP_ENABLE_VSOCK)
+    struct sockaddr_vm s;
+
+    g_memset(&s, 0, sizeof(struct sockaddr_vm));
+    s.svm_family = AF_VSOCK;
+    s.svm_port = atoi(port);
+    s.svm_cid = VMADDR_CID_ANY;
+
+    return bind(sck, (struct sockaddr *)&s, sizeof(struct sockaddr_vm));
+#else
+    return -1;
+#endif
+}
+
+/*****************************************************************************/
+int
+g_sck_vsock_bind_address(int sck, const char *port, const char *address)
+{
+#if defined(XRDP_ENABLE_VSOCK)
+    struct sockaddr_vm s;
+
+    g_memset(&s, 0, sizeof(struct sockaddr_vm));
+    s.svm_family = AF_VSOCK;
+    s.svm_port = atoi(port);
+    s.svm_cid = atoi(address);
+
+    return bind(sck, (struct sockaddr *)&s, sizeof(struct sockaddr_vm));
+#else
+    return -1;
+#endif
+}
+
+
 #if defined(XRDP_ENABLE_IPV6)
 /*****************************************************************************/
 /* Helper function for g_tcp_bind_address.                                   */
@@ -1180,9 +1250,9 @@ g_tcp_accept(int sck)
             {
                 struct sockaddr_in *sock_addr_in = &sock_info.sock_addr_in;
 
-                snprintf(msg, sizeof(msg), "A connection received from %s port %d",
-                         inet_ntoa(sock_addr_in->sin_addr),
-                         ntohs(sock_addr_in->sin_port));
+                g_snprintf(msg, sizeof(msg), "A connection received from %s port %d",
+                           inet_ntoa(sock_addr_in->sin_addr),
+                           ntohs(sock_addr_in->sin_port));
                 log_message(LOG_LEVEL_INFO, "%s", msg);
 
                 break;
@@ -1197,8 +1267,8 @@ g_tcp_accept(int sck)
 
                 inet_ntop(sock_addr_in6->sin6_family,
                           &sock_addr_in6->sin6_addr, addr, sizeof(addr));
-                snprintf(msg, sizeof(msg), "A connection received from %s port %d",
-                         addr, ntohs(sock_addr_in6->sin6_port));
+                g_snprintf(msg, sizeof(msg), "A connection received from %s port %d",
+                           addr, ntohs(sock_addr_in6->sin6_port));
                 log_message(LOG_LEVEL_INFO, "%s", msg);
 
                 break;
@@ -1226,6 +1296,9 @@ g_sck_accept(int sck, char *addr, int addr_bytes, char *port, int port_bytes)
         struct sockaddr_in6 sock_addr_in6;
 #endif
         struct sockaddr_un sock_addr_un;
+#if defined(XRDP_ENABLE_VSOCK)
+        struct sockaddr_vm sock_addr_vm;
+#endif
     } sock_info;
 
     socklen_t sock_len = sizeof(sock_info);
@@ -1273,6 +1346,26 @@ g_sck_accept(int sck, char *addr, int addr_bytes, char *port, int port_bytes)
                 g_snprintf(msg, sizeof(msg), "AF_UNIX connection received");
                 break;
             }
+
+#if defined(XRDP_ENABLE_VSOCK)
+
+            case AF_VSOCK:
+            {
+                struct sockaddr_vm *sock_addr_vm = &sock_info.sock_addr_vm;
+
+                g_snprintf(addr, addr_bytes - 1, "%d", sock_addr_vm->svm_cid);
+                g_snprintf(port, addr_bytes - 1, "%d", sock_addr_vm->svm_port);
+
+                g_snprintf(msg,
+                           sizeof(msg),
+                           "AF_VSOCK connection received from cid: %s port: %s",
+                           addr,
+                           port);
+
+                break;
+            }
+
+#endif
             default:
             {
                 g_strncpy(addr, "", addr_bytes - 1);
@@ -1358,13 +1451,13 @@ g_write_ip_address(int rcv_sck, char *ip_address, int bytes)
 
         if (ok)
         {
-            snprintf(ip_address, bytes, "%s:%d - socket: %d", addr, port, rcv_sck);
+            g_snprintf(ip_address, bytes, "%s:%d - socket: %d", addr, port, rcv_sck);
         }
     }
 
     if (!ok)
     {
-        snprintf(ip_address, bytes, "NULL:NULL - socket: %d", rcv_sck);
+        g_snprintf(ip_address, bytes, "NULL:NULL - socket: %d", rcv_sck);
     }
 
     g_free(addr);
@@ -3749,3 +3842,153 @@ g_mirror_memcpy(void *dst, const void *src, int len)
     return 0;
 }
 
+/*****************************************************************************/
+int
+g_tcp4_socket(void)
+{
+#if defined(XRDP_ENABLE_IPV6ONLY)
+    return -1;
+#else
+    int rv;
+    int option_value;
+    socklen_t option_len;
+
+    rv = socket(AF_INET, SOCK_STREAM, 0);
+    if (rv < 0)
+    {
+        return -1;
+    }
+    option_len = sizeof(option_value);
+    if (getsockopt(rv, SOL_SOCKET, SO_REUSEADDR,
+                   (char *) &option_value, &option_len) == 0)
+    {
+        if (option_value == 0)
+        {
+            option_value = 1;
+            option_len = sizeof(option_value);
+            if (setsockopt(rv, SOL_SOCKET, SO_REUSEADDR,
+                           (char *) &option_value, option_len) < 0)
+            {
+            }
+        }
+    }
+    return rv;
+#endif
+}
+
+/*****************************************************************************/
+int
+g_tcp4_bind_address(int sck, const char *port, const char *address)
+{
+#if defined(XRDP_ENABLE_IPV6ONLY)
+    return -1;
+#else
+    struct sockaddr_in s;
+
+    memset(&s, 0, sizeof(s));
+    s.sin_family = AF_INET;
+    s.sin_addr.s_addr = htonl(INADDR_ANY);
+    s.sin_port = htons((uint16_t) atoi(port));
+    if (inet_aton(address, &s.sin_addr) < 0)
+    {
+        return -1; /* bad address */
+    }
+    if (bind(sck, (struct sockaddr*) &s, sizeof(s)) < 0)
+    {
+        return -1;
+    }
+    return 0;
+#endif
+}
+
+/*****************************************************************************/
+int
+g_tcp6_socket(void)
+{
+#if defined(XRDP_ENABLE_IPV6)
+    int rv;
+    int option_value;
+    socklen_t option_len;
+
+    rv = socket(AF_INET6, SOCK_STREAM, 0);
+    if (rv < 0)
+    {
+        return -1;
+    }
+    option_len = sizeof(option_value);
+    if (getsockopt(rv, IPPROTO_IPV6, IPV6_V6ONLY,
+                   (char *) &option_value, &option_len) == 0)
+    {
+#if defined(XRDP_ENABLE_IPV6ONLY)
+        if (option_value == 0)
+        {
+            option_value = 1;
+#else
+        if (option_value != 0)
+        {
+            option_value = 0;
+#endif
+            option_len = sizeof(option_value);
+            if (setsockopt(rv, IPPROTO_IPV6, IPV6_V6ONLY,
+                           (char *) &option_value, option_len) < 0)
+            {
+            }
+        }
+    }
+    option_len = sizeof(option_value);
+    if (getsockopt(rv, SOL_SOCKET, SO_REUSEADDR,
+                   (char *) &option_value, &option_len) == 0)
+    {
+        if (option_value == 0)
+        {
+            option_value = 1;
+            option_len = sizeof(option_value);
+            if (setsockopt(rv, SOL_SOCKET, SO_REUSEADDR,
+                           (char *) &option_value, option_len) < 0)
+            {
+            }
+        }
+    }
+    return rv;
+#else
+    return -1;
+#endif
+}
+
+/*****************************************************************************/
+int
+g_tcp6_bind_address(int sck, const char *port, const char *address)
+{
+#if defined(XRDP_ENABLE_IPV6)
+    int rv;
+    int error;
+    struct addrinfo hints;
+    struct addrinfo *list;
+    struct addrinfo *i;
+
+    rv = -1;
+    memset(&hints, 0, sizeof(hints));
+    hints.ai_family = AF_UNSPEC;
+    hints.ai_flags = 0;
+    hints.ai_socktype = SOCK_STREAM;
+    hints.ai_protocol = IPPROTO_TCP;
+    error = getaddrinfo(address, port, &hints, &list);
+    if (error == 0)
+    {
+        i = list;
+        while ((i != NULL) && (rv < 0))
+        {
+            rv = bind(sck, i->ai_addr, i->ai_addrlen);
+            i = i->ai_next;
+        }
+        freeaddrinfo(list);
+    }
+    else
+    {
+        return -1;
+    }
+    return rv;
+#else
+    return -1;
+#endif
+}
