@@ -20,6 +20,10 @@
  * This does not do 32 bpp compression, nscodec, rfx, etc
  */
 
+#if defined(HAVE_CONFIG_H)
+#include <config_ac.h>
+#endif
+
 #include "libxrdp.h"
 
 #define BC_MAX_BYTES (16 * 1024)
@@ -644,7 +648,7 @@
     } while (0)
 
 /*****************************************************************************/
-int APP_CC
+int
 xrdp_bitmap_compress(char *in_data, int width, int height,
                      struct stream *s, int bpp, int byte_limit,
                      int start_line, struct stream *temp_s,
