@@ -37,6 +37,7 @@
 #include "xcommon.h"
 #include "chansrv_fuse.h"
 #include "xrdp_sockets.h"
+#include "audin.h"
 
 static struct trans *g_lis_trans = 0;
 static struct trans *g_con_trans = 0;
@@ -59,6 +60,7 @@ int g_cliprdr_chan_id = -1; /* cliprdr */
 int g_rdpsnd_chan_id = -1;  /* rdpsnd  */
 int g_rdpdr_chan_id = -1;   /* rdpdr   */
 int g_rail_chan_id = -1;    /* rail    */
+int g_restrict_outbound_clipboard = 0;
 
 char *g_exec_name;
 tbus g_exec_event;
@@ -405,7 +407,7 @@ process_message_channel_setup(struct stream *s)
 
     if (g_rdpdr_index >= 0)
     {
-        dev_redir_init();
+        devredir_init();
         xfuse_init();
     }
 
@@ -414,6 +416,8 @@ process_message_channel_setup(struct stream *s)
         rail_init();
     }
 
+    audin_init();
+
     return rv;
 }
 
@@ -454,7 +458,7 @@ process_message_channel_data(struct stream *s)
         }
         else if (chan_id == g_rdpdr_chan_id)
         {
-            rv = dev_redir_data_in(s, chan_id, chan_flags, length, total_length);
+            rv = devredir_data_in(s, chan_id, chan_flags, length, total_length);
         }
         else if (chan_id == g_rail_chan_id)
         {
@@ -1408,7 +1412,7 @@ channel_thread_loop(void *in_val)
                 LOGM((LOG_LEVEL_INFO, "channel_thread_loop: g_term_event set"));
                 clipboard_deinit();
                 sound_deinit();
-                dev_redir_deinit();
+                devredir_deinit();
                 rail_deinit();
                 break;
             }
@@ -1430,7 +1434,7 @@ channel_thread_loop(void *in_val)
                           "trans_check_wait_objs error resetting"));
                     clipboard_deinit();
                     sound_deinit();
-                    dev_redir_deinit();
+                    devredir_deinit();
                     rail_deinit();
                     /* delete g_con_trans */
                     trans_delete(g_con_trans);
@@ -1456,7 +1460,7 @@ channel_thread_loop(void *in_val)
             api_con_trans_list_check_wait_objs();
             xcommon_check_wait_objs();
             sound_check_wait_objs();
-            dev_redir_check_wait_objs();
+            devredir_check_wait_objs();
             xfuse_check_wait_objs();
             timeout = -1;
             num_objs = 0;
@@ -1475,7 +1479,7 @@ channel_thread_loop(void *in_val)
                                                 &timeout);
             xcommon_get_wait_objs(objs, &num_objs, &timeout);
             sound_get_wait_objs(objs, &num_objs, &timeout);
-            dev_redir_get_wait_objs(objs, &num_objs, &timeout);
+            devredir_get_wait_objs(objs, &num_objs, &timeout);
             xfuse_get_wait_objs(objs, &num_objs, &timeout);
             get_timeout(&timeout);
         } /* end while (g_obj_wait(objs, num_objs, 0, 0, timeout) == 0) */
@@ -1780,7 +1784,7 @@ main(int argc, char **argv)
     enum logReturns error;
     struct log_config logconfig;
     enum logLevels log_level;
-
+    char *restrict_outbound_clipboard_env;
     g_init("xrdp-chansrv"); /* os_calls */
 
     log_path[255] = 0;
@@ -1791,6 +1795,15 @@ main(int argc, char **argv)
         return 1;
     }
 
+    restrict_outbound_clipboard_env = g_getenv("CHANSRV_RESTRICT_OUTBOUND_CLIPBOARD");
+    if (restrict_outbound_clipboard_env != 0)
+    {
+        if (g_strcmp(restrict_outbound_clipboard_env, "1") == 0)
+        {
+            g_restrict_outbound_clipboard = 1;
+        }
+    }
+
     read_ini();
     pid = g_getpid();
     display_text = g_getenv("DISPLAY");
