@@ -34,6 +34,8 @@
 #include "xrdp_constants.h"
 #include "xrdp_sockets.h"
 #include "chansrv_common.h"
+#include "list.h"
+#include "audin.h"
 
 #if defined(XRDP_FDK_AAC)
 #include <fdk-aac/aacenc_lib.h>
@@ -70,9 +72,11 @@ static struct trans *g_audio_c_trans_in = 0;  /* connection */
 static int    g_training_sent_time = 0;
 static int    g_cBlockNo = 0;
 static int    g_bytes_in_stream = 0;
-static FIFO   g_in_fifo;
-static int    g_bytes_in_fifo = 0;
-static int    g_unacked_frames = 0;
+FIFO   g_in_fifo;
+int    g_bytes_in_fifo = 0;
+static int    g_time_diff = 0;
+static int    g_best_time_diff = 0;
+
 
 static struct stream *g_stream_inp = NULL;
 static struct stream *g_stream_incoming_packet = NULL;
@@ -81,10 +85,11 @@ static struct stream *g_stream_incoming_packet = NULL;
 static char g_buffer[MAX_BBUF_SIZE];
 static int g_buf_index = 0;
 static int g_sent_time[256];
-static int g_sent_flag[256];
 
 static int g_bbuf_size = 1024 * 8; /* may change later */
 
+static struct list *g_ack_time_diff = 0;
+
 struct xr_wave_format_ex
 {
     int wFormatTag;
@@ -236,6 +241,8 @@ static struct xr_wave_format_ex *g_wave_inp_formats[] =
     0
 };
 
+static int g_rdpsnd_can_rec = 0;
+
 static int g_client_input_format_index = 0;
 static int g_server_input_format_index = 0;
 
@@ -340,7 +347,7 @@ sound_send_training(void)
     out_uint16_le(s, SNDC_TRAINING);
     size_ptr = s->p;
     out_uint16_le(s, 0); /* size, set later */
-    time = g_time2();
+    time = g_time3();
     g_training_sent_time = time;
     out_uint16_le(s, time);
     out_uint16_le(s, 1024);
@@ -883,18 +890,6 @@ sound_send_wave_data_chunk(char *data, int data_bytes)
         return 1;
     }
 
-    LOG(20, ("sound_send_wave_data_chunk: g_sent_flag[%d] = %d",
-            g_cBlockNo + 1, g_sent_flag[(g_cBlockNo + 1) & 0xff]));
-    if (g_sent_flag[(g_cBlockNo + 1) & 0xff] & 1)
-    {
-        LOG(10, ("sound_send_wave_data_chunk: no room"));
-        return 2;
-    }
-    else
-    {
-        LOG(10, ("sound_send_wave_data_chunk: got room"));
-    }
-
     /* compress, if available */
     format_index = g_current_client_format_index;
     data_bytes = sound_wave_compress(data, data_bytes, &format_index);
@@ -908,14 +903,12 @@ sound_send_wave_data_chunk(char *data, int data_bytes)
     out_uint16_le(s, SNDC_WAVE);
     size_ptr = s->p;
     out_uint16_le(s, 0); /* size, set later */
-    time = g_time2();
+    time = g_time3();
     out_uint16_le(s, time);
     out_uint16_le(s, format_index); /* wFormatNo */
     g_cBlockNo++;
-    g_unacked_frames++;
     out_uint8(s, g_cBlockNo);
     g_sent_time[g_cBlockNo & 0xff] = time;
-    g_sent_flag[g_cBlockNo & 0xff] = 1;
 
     LOG(10, ("sound_send_wave_data_chunk: sending time %d, g_cBlockNo %d",
              time & 0xffff, g_cBlockNo & 0xff));
@@ -956,6 +949,13 @@ sound_send_wave_data(char *data, int data_bytes)
     int res;
 
     LOG(10, ("sound_send_wave_data: sending %d bytes", data_bytes));
+    if (g_time_diff > g_best_time_diff + 250)
+    {
+        data_bytes = data_bytes / 4;
+        data_bytes = data_bytes & ~3;
+        g_memset(data, 0, data_bytes);
+        g_time_diff = 0;
+    }
     data_index = 0;
     error = 0;
     while (data_bytes > 0)
@@ -1005,17 +1005,8 @@ sound_send_close(void)
 
     LOG(10, ("sound_send_close:"));
 
-    /* send any left over data */
-    if (g_buf_index)
-    {
-        if (sound_send_wave_data_chunk(g_buffer, g_buf_index) != 0)
-        {
-            LOG(10, ("sound_send_close: sound_send_wave_data_chunk failed"));
-            return 1;
-        }
-    }
+    g_best_time_diff = 0;
     g_buf_index = 0;
-    g_memset(g_sent_flag, 0, sizeof(g_sent_flag));
 
     /* send close msg */
     make_stream(s);
@@ -1040,7 +1031,7 @@ sound_process_training(struct stream *s, int size)
 {
     int time_diff;
 
-    time_diff = g_time2() - g_training_sent_time;
+    time_diff = g_time3() - g_training_sent_time;
     LOG(0, ("sound_process_training: round trip time %u", time_diff));
     return 0;
 }
@@ -1052,42 +1043,39 @@ sound_process_wave_confirm(struct stream *s, int size)
 {
     int wTimeStamp;
     int cConfirmedBlockNo;
-    int cleared_count;
     int time;
     int time_diff;
-    int block_no;
-    int block_no_clamped;
-    int found;
     int index;
+    int acc;
 
-    time = g_time2();
+    time = g_time3();
     in_uint16_le(s, wTimeStamp);
     in_uint8(s, cConfirmedBlockNo);
     time_diff = time - g_sent_time[cConfirmedBlockNo & 0xff];
-    cleared_count = 0;
-    found = 0;
-    block_no = g_cBlockNo;
-    for (index = 0; index < g_unacked_frames; index++)
-    {
-        block_no_clamped = block_no & 0xff;
-        if ((cConfirmedBlockNo == block_no_clamped) || found)
-        {
-            found = 1;
-            if (g_sent_flag[block_no_clamped] & 1)
-            {
-                LOG(10, ("sound_process_wave_confirm: clearing %d",
-                    block_no_clamped));
-                g_sent_flag[block_no_clamped] &= ~1;
-                cleared_count++;
-            }
-        }
-        block_no--;
-    }
+
     LOG(10, ("sound_process_wave_confirm: wTimeStamp %d, "
-        "cConfirmedBlockNo %d time diff %d cleared_count %d "
-        "g_unacked_frames %d", wTimeStamp, cConfirmedBlockNo, time_diff,
-        cleared_count, g_unacked_frames));
-    g_unacked_frames -= cleared_count;
+        "cConfirmedBlockNo %d time diff %d",
+        wTimeStamp, cConfirmedBlockNo, time_diff));
+
+    acc = 0;
+    list_add_item(g_ack_time_diff, time_diff);
+    if (g_ack_time_diff->count >= 50)
+    {
+        while (g_ack_time_diff->count > 50)
+        {
+            list_remove_item(g_ack_time_diff, 0);
+        }
+        for (index = 0; index < g_ack_time_diff->count; index++)
+        {
+            acc += list_get_item(g_ack_time_diff, index);
+        }
+        acc = acc / g_ack_time_diff->count;
+        if ((g_best_time_diff < 1) || (g_best_time_diff > acc))
+        {
+            g_best_time_diff = acc;
+        }
+    }
+    g_time_diff = acc;
     return 0;
 }
 
@@ -1219,7 +1207,6 @@ sound_init(void)
 {
     LOG(0, ("sound_init:"));
 
-    g_memset(g_sent_flag, 0, sizeof(g_sent_flag));
     g_stream_incoming_packet = NULL;
 
     /* init sound output */
@@ -1242,6 +1229,12 @@ sound_init(void)
     g_client_does_mp3lame = 0;
     g_client_mp3lame_index = 0;
 
+    if (g_ack_time_diff == 0)
+    {
+        g_ack_time_diff = list_create();
+    }
+    list_clear(g_ack_time_diff);
+
     return 0;
 }
 
@@ -1445,6 +1438,7 @@ sound_check_wait_objs(void)
 static int
 sound_send_server_input_formats(void)
 {
+#if defined(XRDP_RDPSNDAUDIN)
     struct stream *s;
     int bytes;
     int index;
@@ -1499,6 +1493,10 @@ sound_send_server_input_formats(void)
     bytes = (int)(s->end - s->data);
     send_channel_data(g_rdpsnd_chan_id, s->data, bytes);
     free_stream(s);
+#else
+    /* avoid warning */
+    (void)g_wave_inp_formats;
+#endif
     return 0;
 }
 
@@ -1570,6 +1568,10 @@ sound_process_input_formats(struct stream *s, int size)
 
     LOG(10, ("sound_process_input_formats: size=%d", size));
 
+    if (g_getenv("XRDP_NO_RDPSND_REC") == NULL)
+    {
+        g_rdpsnd_can_rec = 1;
+    }
     in_uint8s(s, 8); /* skip 8 bytes */
     in_uint16_le(s, num_formats);
     in_uint8s(s, 2); /* skip version */
@@ -1782,11 +1784,25 @@ sound_sndsrvr_source_data_in(struct trans *trans)
     }
     else if (cmd == PA_CMD_START_REC)
     {
-        sound_input_start_recording();
+        if (g_rdpsnd_can_rec)
+        {
+            sound_input_start_recording();
+        }
+        else
+        {
+            audin_start();
+        }
     }
     else if (cmd == PA_CMD_STOP_REC)
     {
-        sound_input_stop_recording();
+        if (g_rdpsnd_can_rec)
+        {
+            sound_input_stop_recording();
+        }
+        else
+        {
+            audin_stop();
+        }
     }
 
     xstream_free(s);
