@@ -1,21 +1,20 @@
-/*
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-   xrdp: A Remote Desktop Protocol server.
-   Copyright (C) Jay Sorg 2005-2010
-*/
+/**
+ * xrdp: A Remote Desktop Protocol server.
+ *
+ * Copyright (C) Jay Sorg 2004-2012
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 /**
  *
@@ -39,7 +38,7 @@
  * @param skipVchk if set to !0 skips the version control (to be used after
  *                 scp_vXs_accept() )
  *
- * this function places in *s the address of a newely allocated SCP_SESSION structure
+ * this function places in *s the address of a newly allocated SCP_SESSION structure
  * that should be free()d
  */
 enum SCP_SERVER_STATES_E
@@ -49,15 +48,16 @@ scp_v1s_accept(struct SCP_CONNECTION* c, struct SCP_SESSION** s, int skipVchk);
  *
  * @brief denies connection to sesman
  * @param c connection descriptor
- * @param reason pointer to a string containinge the reason for denying connection
+ * @param reason pointer to a string containing the reason for denying connection
  *
  */
 /* 002 */
 enum SCP_SERVER_STATES_E
-scp_v1s_deny_connection(struct SCP_CONNECTION* c, char* reason);
+scp_v1s_deny_connection(struct SCP_CONNECTION* c, const char *reason);
 
 enum SCP_SERVER_STATES_E
-scp_v1s_request_password(struct SCP_CONNECTION* c, struct SCP_SESSION* s, char* reason);
+scp_v1s_request_password(struct SCP_CONNECTION* c, struct SCP_SESSION* s,
+                         const char *reason);
 
 /* 020 */
 enum SCP_SERVER_STATES_E
@@ -73,7 +73,7 @@ scp_v1s_connect_new_session(struct SCP_CONNECTION* c, SCP_DISPLAY d);
 
 /* 032 */
 enum SCP_SERVER_STATES_E
-scp_v1s_connection_error(struct SCP_CONNECTION* c, char* error);
+scp_v1s_connection_error(struct SCP_CONNECTION* c, const char *error);
 
 /* 040 */
 enum SCP_SERVER_STATES_E
