@@ -24,6 +24,10 @@
  *
  */
 
+#if defined(HAVE_CONFIG_H)
+#include <config_ac.h>
+#endif
+
 #include "sesman.h"
 
 #include "libscp.h"
@@ -33,7 +37,7 @@ extern struct config_sesman *g_cfg; /* in sesman.c */
 static void parseCommonStates(enum SCP_SERVER_STATES_E e, const char *f);
 
 /******************************************************************************/
-void DEFAULT_CC
+void
 scp_v1_mng_process(struct SCP_CONNECTION *c, struct SCP_SESSION *s)
 {
     long data;
@@ -80,19 +84,13 @@ scp_v1_mng_process(struct SCP_CONNECTION *c, struct SCP_SESSION *s)
                 /* list disconnected sessions */
                 slist = session_get_byuser(NULL, &scount, SESMAN_SESSION_STATUS_ALL);
                 LOG_DBG("sessions on TS: %d (slist: %x)", scount, slist);
-
                 if (0 == slist)
                 {
-                    //          e=scp_v1s_connection_error(c, "Internal error");
                     log_message(LOG_LEVEL_INFO, "No sessions on Terminal Server");
-                    end = 0;
-                }
-                else
-                {
-                    e = scp_v1s_mng_list_sessions(c, s, scount, slist);
-                    g_free(slist);
                 }
 
+                e = scp_v1s_mng_list_sessions(c, s, scount, slist);
+                g_free(slist);
                 break;
             default:
                 /* we check the other errors */
