@@ -33,7 +33,7 @@
  * @param sig The received signal
  *
  */
-void DEFAULT_CC
+void
 sig_sesman_shutdown(int sig);
 
 /**
@@ -42,7 +42,7 @@ sig_sesman_shutdown(int sig);
  * @param sig The received signal
  *
  */
-void DEFAULT_CC
+void
 sig_sesman_reload_cfg(int sig);
 
 /**
@@ -51,7 +51,7 @@ sig_sesman_reload_cfg(int sig);
  * @param sig The received signal
  *
  */
-void DEFAULT_CC
+void
 sig_sesman_session_end(int sig);
 
 /**
@@ -59,7 +59,7 @@ sig_sesman_session_end(int sig);
  * @brief signal handling thread
  *
  */
-void* DEFAULT_CC
+void*
 sig_handler_thread(void* arg);
 
 #endif
