@@ -18,6 +18,10 @@
  * libvnc
  */
 
+#if defined(HAVE_CONFIG_H)
+#include <config_ac.h>
+#endif
+
 #include "vnc.h"
 #include "log.h"
 #include "trans.h"
@@ -37,11 +41,11 @@
 
 #define AS_LOG_MESSAGE log_message
 
-static int APP_CC
+static int
 lib_mod_process_message(struct vnc *v, struct stream *s);
 
 /******************************************************************************/
-static int APP_CC
+static int
 lib_send_copy(struct vnc *v, struct stream *s)
 {
     return trans_write_copy_s(v->trans, s);
@@ -53,7 +57,7 @@ lib_send_copy(struct vnc *v, struct stream *s)
    on the wire
    'bytes' in, contains 16 bytes server random
            out, random and 'passwd' conbined */
-static void APP_CC
+static void
 rfbEncryptBytes(char *bytes, const char *passwd)
 {
     char key[24];
@@ -74,7 +78,7 @@ rfbEncryptBytes(char *bytes, const char *passwd)
 
 /******************************************************************************/
 /* sha1 hash 'passwd', create a string from the hash and call rfbEncryptBytes */
-static void APP_CC
+static void
 rfbHashEncryptBytes(char *bytes, const char *passwd)
 {
     char passwd_hash[20];
@@ -98,7 +102,7 @@ rfbHashEncryptBytes(char *bytes, const char *passwd)
 }
 
 /******************************************************************************/
-static int DEFAULT_CC
+static int
 lib_process_channel_data(struct vnc *v, int chanid, int flags, int size,
                          struct stream *s, int total_size)
 {
@@ -252,7 +256,7 @@ lib_process_channel_data(struct vnc *v, int chanid, int flags, int size,
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 lib_mod_event(struct vnc *v, int msg, long param1, long param2,
               long param3, long param4)
 {
@@ -376,20 +380,23 @@ lib_mod_event(struct vnc *v, int msg, long param1, long param2,
     }
     else if (msg == 200) /* invalidate */
     {
-        /* FramebufferUpdateRequest */
-        init_stream(s, 8192);
-        out_uint8(s, 3);
-        out_uint8(s, 0);
-        x = (param1 >> 16) & 0xffff;
-        out_uint16_be(s, x);
-        y = param1 & 0xffff;
-        out_uint16_be(s, y);
-        cx = (param2 >> 16) & 0xffff;
-        out_uint16_be(s, cx);
-        cy = param2 & 0xffff;
-        out_uint16_be(s, cy);
-        s_mark_end(s);
-        error = lib_send_copy(v, s);
+        if (v->suppress_output == 0)
+        {
+            /* FramebufferUpdateRequest */
+            init_stream(s, 8192);
+            out_uint8(s, 3);
+            out_uint8(s, 0);
+            x = (param1 >> 16) & 0xffff;
+            out_uint16_be(s, x);
+            y = param1 & 0xffff;
+            out_uint16_be(s, y);
+            cx = (param2 >> 16) & 0xffff;
+            out_uint16_be(s, cx);
+            cy = param2 & 0xffff;
+            out_uint16_be(s, cy);
+            s_mark_end(s);
+            error = lib_send_copy(v, s);
+        }
     }
 
     free_stream(s);
@@ -397,7 +404,7 @@ lib_mod_event(struct vnc *v, int msg, long param1, long param2,
 }
 
 //******************************************************************************
-int DEFAULT_CC
+int
 get_pixel_safe(char *data, int x, int y, int width, int height, int bpp)
 {
     int start = 0;
@@ -466,7 +473,7 @@ get_pixel_safe(char *data, int x, int y, int width, int height, int bpp)
 }
 
 /******************************************************************************/
-void DEFAULT_CC
+void
 set_pixel_safe(char *data, int x, int y, int width, int height, int bpp,
                int pixel)
 {
@@ -525,7 +532,7 @@ set_pixel_safe(char *data, int x, int y, int width, int height, int bpp,
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 split_color(int pixel, int *r, int *g, int *b, int bpp, int *palette)
 {
     if (bpp == 8)
@@ -564,7 +571,7 @@ split_color(int pixel, int *r, int *g, int *b, int bpp, int *palette)
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 make_color(int r, int g, int b, int bpp)
 {
     if (bpp == 24)
@@ -580,7 +587,7 @@ make_color(int r, int g, int b, int bpp)
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 lib_framebuffer_update(struct vnc *v)
 {
     char *d1;
@@ -738,16 +745,19 @@ lib_framebuffer_update(struct vnc *v)
 
     if (error == 0)
     {
-        /* FramebufferUpdateRequest */
-        init_stream(s, 8192);
-        out_uint8(s, 3);
-        out_uint8(s, 1);
-        out_uint16_be(s, 0);
-        out_uint16_be(s, 0);
-        out_uint16_be(s, v->mod_width);
-        out_uint16_be(s, v->mod_height);
-        s_mark_end(s);
-        error = lib_send_copy(v, s);
+        if (v->suppress_output == 0)
+        {
+            /* FramebufferUpdateRequest */
+            init_stream(s, 8192);
+            out_uint8(s, 3);
+            out_uint8(s, 1);
+            out_uint16_be(s, 0);
+            out_uint16_be(s, 0);
+            out_uint16_be(s, v->mod_width);
+            out_uint16_be(s, v->mod_height);
+            s_mark_end(s);
+            error = lib_send_copy(v, s);
+        }
     }
 
     free_stream(s);
@@ -757,7 +767,7 @@ lib_framebuffer_update(struct vnc *v)
 
 /******************************************************************************/
 /* clip data from the vnc server */
-int DEFAULT_CC
+int
 lib_clip_data(struct vnc *v)
 {
     struct stream *s;
@@ -807,7 +817,7 @@ lib_clip_data(struct vnc *v)
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 lib_palette_update(struct vnc *v)
 {
     struct stream *s;
@@ -863,7 +873,7 @@ lib_palette_update(struct vnc *v)
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 lib_bell_trigger(struct vnc *v)
 {
     int error;
@@ -873,7 +883,7 @@ lib_bell_trigger(struct vnc *v)
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 lib_mod_signal(struct vnc *v)
 {
     g_writeln("lib_mod_signal: not used");
@@ -881,7 +891,7 @@ lib_mod_signal(struct vnc *v)
 }
 
 /******************************************************************************/
-static int APP_CC
+static int
 lib_mod_process_message(struct vnc *v, struct stream *s)
 {
     char type;
@@ -912,7 +922,7 @@ lib_mod_process_message(struct vnc *v, struct stream *s)
         }
         else
         {
-            g_sprintf(text, "VNC unknown in lib_mod_signal %d", type);
+            g_sprintf(text, "VNC unknown in lib_mod_process_message %d", type);
             v->server_msg(v, text, 1);
         }
     }
@@ -921,7 +931,7 @@ lib_mod_process_message(struct vnc *v, struct stream *s)
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 lib_mod_start(struct vnc *v, int w, int h, int bpp)
 {
     v->server_begin_update(v);
@@ -935,7 +945,7 @@ lib_mod_start(struct vnc *v, int w, int h, int bpp)
 }
 
 /******************************************************************************/
-static int APP_CC
+static int
 lib_open_clip_channel(struct vnc *v)
 {
     char init_data[12] = { 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
@@ -951,7 +961,7 @@ lib_open_clip_channel(struct vnc *v)
 }
 
 /******************************************************************************/
-static int APP_CC
+static int
 lib_data_in(struct trans *trans)
 {
     struct vnc *self;
@@ -987,7 +997,7 @@ lib_data_in(struct trans *trans)
 /*
   return error
 */
-int DEFAULT_CC
+int
 lib_mod_connect(struct vnc *v)
 {
     char cursor_data[32 * (32 * 3)];
@@ -1336,17 +1346,20 @@ lib_mod_connect(struct vnc *v)
 
     if (error == 0)
     {
-        /* FramebufferUpdateRequest */
-        init_stream(s, 8192);
-        out_uint8(s, 3);
-        out_uint8(s, 0);
-        out_uint16_be(s, 0);
-        out_uint16_be(s, 0);
-        out_uint16_be(s, v->mod_width);
-        out_uint16_be(s, v->mod_height);
-        v->server_msg(v, "VNC sending framebuffer update request", 0);
-        s_mark_end(s);
-        error = trans_force_write_s(v->trans, s);
+        if (v->suppress_output == 0)
+        {
+            /* FramebufferUpdateRequest */
+            init_stream(s, 8192);
+            out_uint8(s, 3);
+            out_uint8(s, 0);
+            out_uint16_be(s, 0);
+            out_uint16_be(s, 0);
+            out_uint16_be(s, v->mod_width);
+            out_uint16_be(s, v->mod_height);
+            v->server_msg(v, "VNC sending framebuffer update request", 0);
+            s_mark_end(s);
+            error = trans_force_write_s(v->trans, s);
+        }
     }
 
     if (error == 0)
@@ -1388,7 +1401,6 @@ lib_mod_connect(struct vnc *v)
         trans_delete(v->trans);
         v->trans = 0;
         v->server_msg(v, "some problem", 0);
-        LIB_DEBUG(mod, "out lib_mod_connect error");
         return 1;
     }
     else
@@ -1403,7 +1415,7 @@ lib_mod_connect(struct vnc *v)
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 lib_mod_end(struct vnc *v)
 {
     if (v->vnc_desktop != 0)
@@ -1415,8 +1427,8 @@ lib_mod_end(struct vnc *v)
 }
 
 /******************************************************************************/
-int DEFAULT_CC
-lib_mod_set_param(struct vnc *v, const char *name, char *value)
+int
+lib_mod_set_param(struct vnc *v, const char *name, const char *value)
 {
     if (g_strcasecmp(name, "username") == 0)
     {
@@ -1453,7 +1465,7 @@ lib_mod_set_param(struct vnc *v, const char *name, char *value)
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_get_wait_objs(struct vnc *v, tbus *read_objs, int *rcount,
                       tbus *write_objs, int *wcount, int *timeout)
 {
@@ -1473,7 +1485,7 @@ lib_mod_get_wait_objs(struct vnc *v, tbus *read_objs, int *rcount,
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_check_wait_objs(struct vnc *v)
 {
     int rv;
@@ -1489,6 +1501,43 @@ lib_mod_check_wait_objs(struct vnc *v)
     return rv;
 }
 
+/******************************************************************************/
+/* return error */
+int
+lib_mod_frame_ack(struct vnc* v, int flags, int frame_id)
+{
+    return 0;
+}
+
+/******************************************************************************/
+/* return error */
+int
+lib_mod_suppress_output(struct vnc* v, int suppress,
+                        int left, int top, int right, int bottom)
+{
+    int error;
+    struct stream *s;
+
+    error = 0;
+    v->suppress_output = suppress;
+    if (suppress == 0)
+    {
+        /* FramebufferUpdateRequest */
+        make_stream(s);
+        init_stream(s, 8192);
+        out_uint8(s, 3);
+        out_uint8(s, 0);
+        out_uint16_be(s, 0);
+        out_uint16_be(s, 0);
+        out_uint16_be(s, v->mod_width);
+        out_uint16_be(s, v->mod_height);
+        s_mark_end(s);
+        error = lib_send_copy(v, s);
+        free_stream(s);
+    }
+    return error;
+}
+
 /******************************************************************************/
 tintptr EXPORT_CC
 mod_init(void)
@@ -1508,6 +1557,8 @@ mod_init(void)
     v->mod_set_param = lib_mod_set_param;
     v->mod_get_wait_objs = lib_mod_get_wait_objs;
     v->mod_check_wait_objs = lib_mod_check_wait_objs;
+    v->mod_frame_ack = lib_mod_frame_ack;
+    v->mod_suppress_output = lib_mod_suppress_output;
     return (tintptr) v;
 }
 
