@@ -18,6 +18,10 @@
  * libxup main file
  */
 
+#if defined(HAVE_CONFIG_H)
+#include <config_ac.h>
+#endif
+
 #include "xup.h"
 #include "log.h"
 #include "trans.h"
@@ -28,11 +32,11 @@
 #define LLOGLN(_level, _args) \
     do { if (_level < LOG_LEVEL) { g_writeln _args ; } } while (0)
 
-static int APP_CC
+static int
 lib_mod_process_message(struct mod *mod, struct stream *s);
 
 /******************************************************************************/
-static int APP_CC
+static int
 lib_send_copy(struct mod *mod, struct stream *s)
 {
     return trans_write_copy_s(mod->trans, s);
@@ -40,7 +44,7 @@ lib_send_copy(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_start(struct mod *mod, int w, int h, int bpp)
 {
     LIB_DEBUG(mod, "in lib_mod_start");
@@ -52,7 +56,7 @@ lib_mod_start(struct mod *mod, int w, int h, int bpp)
 }
 
 /******************************************************************************/
-static int APP_CC
+static int
 lib_mod_log_peer(struct mod *mod)
 {
     int my_pid;
@@ -79,7 +83,7 @@ lib_mod_log_peer(struct mod *mod)
 }
 
 /******************************************************************************/
-static int APP_CC
+static int
 lib_data_in(struct trans *trans)
 {
     struct mod *self;
@@ -136,7 +140,7 @@ lib_data_in(struct trans *trans)
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_connect(struct mod *mod)
 {
     int error;
@@ -212,7 +216,8 @@ lib_mod_connect(struct mod *mod)
         if (trans_connect(mod->trans, mod->ip, con_port, 3000) == 0)
         {
             LLOGLN(0, ("lib_mod_connect: connected to Xserver "
-                   "(Xorg or X11rdp) sck %ld", mod->trans->sck));
+                   "(Xorg or X11rdp) sck %lld",
+                   (long long) (mod->trans->sck)));
             error = 0;
         }
 
@@ -221,6 +226,11 @@ lib_mod_connect(struct mod *mod)
             break;
         }
 
+        if (mod->server_is_term(mod))
+        {
+            break;
+        }
+
         i++;
 
         if (i >= 60)
@@ -324,7 +334,7 @@ lib_mod_connect(struct mod *mod)
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_event(struct mod *mod, int msg, tbus param1, tbus param2,
               tbus param3, tbus param4)
 {
@@ -395,7 +405,7 @@ lib_mod_event(struct mod *mod, int msg, tbus param1, tbus param2,
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_fill_rect(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -414,7 +424,7 @@ process_server_fill_rect(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_screen_blt(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -437,7 +447,7 @@ process_server_screen_blt(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_paint_rect(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -470,7 +480,7 @@ process_server_paint_rect(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_set_clip(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -489,7 +499,7 @@ process_server_set_clip(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_reset_clip(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -500,7 +510,7 @@ process_server_reset_clip(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_set_fgcolor(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -513,7 +523,7 @@ process_server_set_fgcolor(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_set_bgcolor(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -526,7 +536,7 @@ process_server_set_bgcolor(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_set_opcode(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -539,7 +549,7 @@ process_server_set_opcode(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_set_pen(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -554,7 +564,7 @@ process_server_set_pen(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_draw_line(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -573,7 +583,7 @@ process_server_draw_line(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_set_cursor(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -592,7 +602,7 @@ process_server_set_cursor(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_create_os_surface(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -609,7 +619,7 @@ process_server_create_os_surface(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_switch_os_surface(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -622,7 +632,7 @@ process_server_switch_os_surface(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_delete_os_surface(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -635,7 +645,7 @@ process_server_delete_os_surface(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_paint_rect_os(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -661,7 +671,7 @@ process_server_paint_rect_os(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_set_hints(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -676,7 +686,7 @@ process_server_set_hints(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_window_new_update(struct mod *mod, struct stream *s)
 {
     int flags;
@@ -759,7 +769,7 @@ process_server_window_new_update(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_window_delete(struct mod *mod, struct stream *s)
 {
     int window_id;
@@ -773,7 +783,7 @@ process_server_window_delete(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_window_show(struct mod* mod, struct stream* s)
 {
     int window_id;
@@ -792,7 +802,7 @@ process_server_window_show(struct mod* mod, struct stream* s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_add_char(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -820,7 +830,7 @@ process_server_add_char(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_add_char_alpha(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -848,7 +858,7 @@ process_server_add_char_alpha(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_draw_text(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -891,7 +901,7 @@ process_server_draw_text(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_create_os_surface_bpp(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -911,7 +921,7 @@ process_server_create_os_surface_bpp(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_paint_rect_bpp(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -946,7 +956,7 @@ process_server_paint_rect_bpp(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_composite(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -1001,7 +1011,7 @@ process_server_composite(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_set_pointer_ex(struct mod *mod, struct stream *s)
 {
     int rv;
@@ -1024,7 +1034,7 @@ process_server_set_pointer_ex(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 send_paint_rect_ack(struct mod *mod, int flags, int x, int y, int cx, int cy,
                     int frame_id)
 {
@@ -1052,7 +1062,7 @@ send_paint_rect_ack(struct mod *mod, int flags, int x, int y, int cx, int cy,
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 process_server_paint_rect_shmem(struct mod *amod, struct stream *s)
 {
     int rv;
@@ -1101,6 +1111,19 @@ process_server_paint_rect_shmem(struct mod *amod, struct stream *s)
             amod->screen_shmem_id_mapped = 1;
         }
     }
+    else if (amod->screen_shmem_id != shmem_id)
+    {
+        amod->screen_shmem_id = shmem_id;
+        g_shmdt(amod->screen_shmem_pixels);
+        amod->screen_shmem_pixels = (char *) g_shmat(amod->screen_shmem_id);
+        if (amod->screen_shmem_pixels == (void*)-1)
+        {
+            /* failed */
+            amod->screen_shmem_id = 0;
+            amod->screen_shmem_pixels = 0;
+            amod->screen_shmem_id_mapped = 0;
+        }
+    }
     if (amod->screen_shmem_pixels != 0)
     {
         bmpdata = amod->screen_shmem_pixels + shmem_offset;
@@ -1117,7 +1140,7 @@ process_server_paint_rect_shmem(struct mod *amod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 send_paint_rect_ex_ack(struct mod *mod, int flags, int frame_id)
 {
     int len;
@@ -1140,7 +1163,34 @@ send_paint_rect_ex_ack(struct mod *mod, int flags, int frame_id)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
+send_suppress_output(struct mod *mod, int suppress,
+                     int left, int top, int right, int bottom)
+{
+    int len;
+    struct stream *s;
+
+    make_stream(s);
+    init_stream(s, 8192);
+    s_push_layer(s, iso_hdr, 4);
+    out_uint16_le(s, 108);
+    out_uint32_le(s, suppress);
+    out_uint32_le(s, left);
+    out_uint32_le(s, top);
+    out_uint32_le(s, right);
+    out_uint32_le(s, bottom);
+    s_mark_end(s);
+    len = (int)(s->end - s->data);
+    s_pop_layer(s, iso_hdr);
+    out_uint32_le(s, len);
+    lib_send_copy(mod, s);
+    free_stream(s);
+    return 0;
+}
+
+/******************************************************************************/
+/* return error */
+static int
 process_server_paint_rect_shmem_ex(struct mod *amod, struct stream *s)
 {
     int num_drects;
@@ -1212,6 +1262,19 @@ process_server_paint_rect_shmem_ex(struct mod *amod, struct stream *s)
                 amod->screen_shmem_id_mapped = 1;
             }
         }
+        else if (amod->screen_shmem_id != shmem_id)
+        {
+            amod->screen_shmem_id = shmem_id;
+            g_shmdt(amod->screen_shmem_pixels);
+            amod->screen_shmem_pixels = (char *) g_shmat(amod->screen_shmem_id);
+            if (amod->screen_shmem_pixels == (void*)-1)
+            {
+                /* failed */
+                amod->screen_shmem_id = 0;
+                amod->screen_shmem_pixels = 0;
+                amod->screen_shmem_id_mapped = 0;
+            }
+        }
         if (amod->screen_shmem_pixels != 0)
         {
             bmpdata = amod->screen_shmem_pixels + shmem_offset;
@@ -1241,7 +1304,7 @@ process_server_paint_rect_shmem_ex(struct mod *amod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 lib_mod_process_orders(struct mod *mod, int type, struct stream *s)
 {
     int rv;
@@ -1350,7 +1413,7 @@ lib_mod_process_orders(struct mod *mod, int type, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 lib_send_client_info(struct mod *mod)
 {
     struct stream *s;
@@ -1374,7 +1437,7 @@ lib_send_client_info(struct mod *mod)
 
 /******************************************************************************/
 /* return error */
-static int APP_CC
+static int
 lib_mod_process_message(struct mod *mod, struct stream *s)
 {
     int num_orders;
@@ -1456,7 +1519,7 @@ lib_mod_process_message(struct mod *mod, struct stream *s)
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_signal(struct mod *mod)
 {
     g_writeln("lib_mod_signal: not used");
@@ -1465,7 +1528,7 @@ lib_mod_signal(struct mod *mod)
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_end(struct mod *mod)
 {
     if (mod->screen_shmem_pixels != 0)
@@ -1478,8 +1541,8 @@ lib_mod_end(struct mod *mod)
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
-lib_mod_set_param(struct mod *mod, const char *name, char *value)
+int
+lib_mod_set_param(struct mod *mod, const char *name, const char *value)
 {
     if (g_strcasecmp(name, "username") == 0)
     {
@@ -1507,7 +1570,7 @@ lib_mod_set_param(struct mod *mod, const char *name, char *value)
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_get_wait_objs(struct mod *mod, tbus *read_objs, int *rcount,
                       tbus *write_objs, int *wcount, int *timeout)
 {
@@ -1524,7 +1587,7 @@ lib_mod_get_wait_objs(struct mod *mod, tbus *read_objs, int *rcount,
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_check_wait_objs(struct mod *mod)
 {
     int rv;
@@ -1543,7 +1606,7 @@ lib_mod_check_wait_objs(struct mod *mod)
 
 /******************************************************************************/
 /* return error */
-int DEFAULT_CC
+int
 lib_mod_frame_ack(struct mod *amod, int flags, int frame_id)
 {
     LLOGLN(10, ("lib_mod_frame_ack: flags 0x%8.8x frame_id %d", flags, frame_id));
@@ -1551,6 +1614,18 @@ lib_mod_frame_ack(struct mod *amod, int flags, int frame_id)
     return 0;
 }
 
+/******************************************************************************/
+/* return error */
+int
+lib_mod_suppress_output(struct mod *amod, int suppress,
+                        int left, int top, int right, int bottom)
+{
+    LLOGLN(10, ("lib_mod_suppress_output: suppress 0x%8.8x left %d top %d "
+           "right %d bottom %d", suppress, left, top, right, bottom));
+    send_suppress_output(amod, suppress, left, top, right, bottom);
+    return 0;
+}
+
 /******************************************************************************/
 tintptr EXPORT_CC
 mod_init(void)
@@ -1570,6 +1645,7 @@ mod_init(void)
     mod->mod_get_wait_objs = lib_mod_get_wait_objs;
     mod->mod_check_wait_objs = lib_mod_check_wait_objs;
     mod->mod_frame_ack = lib_mod_frame_ack;
+    mod->mod_suppress_output = lib_mod_suppress_output;
     return (tintptr) mod;
 }
 
