@@ -26,7 +26,7 @@
 #include "xrdp_client_info.h"
 #include "xrdp_rail.h"
 
-#define CURRENT_MOD_VER 3
+#define CURRENT_MOD_VER 4
 
 struct mod
 {
@@ -39,13 +39,15 @@ struct mod
                    tbus param3, tbus param4);
   int (*mod_signal)(struct mod* v);
   int (*mod_end)(struct mod* v);
-  int (*mod_set_param)(struct mod* v, const char *name, char* value);
+  int (*mod_set_param)(struct mod *v, const char *name, const char *value);
   int (*mod_session_change)(struct mod* v, int, int);
   int (*mod_get_wait_objs)(struct mod* v, tbus* read_objs, int* rcount,
                            tbus* write_objs, int* wcount, int* timeout);
   int (*mod_check_wait_objs)(struct mod* v);
   int (*mod_frame_ack)(struct mod* v, int flags, int frame_id);
-  tintptr mod_dumby[100 - 10]; /* align, 100 minus the number of mod
+  int (*mod_suppress_output)(struct mod* v, int suppress,
+                             int left, int top, int right, int bottom);
+  tintptr mod_dumby[100 - 11]; /* align, 100 minus the number of mod
                                  functions above */
   /* server functions */
   int (*server_begin_update)(struct mod* v);
